<?php

function phone_repair_find_template_path( $name ) {
	if ( empty( $name ) ) {
		return false;
	}
	$paths = array(
		trailingslashit( get_stylesheet_directory() ) . $name . '.php',
		trailingslashit( get_template_directory() ) . $name . '.php',
		PHONE_REPAIR_PLUGIN_DIR_PATH . $name . '.php',
	);
	foreach ( $paths as $path ) {
		if ( is_file( $path ) ) {
			return $path;
		}
	}
	return false;
}

function phone_repair_get_vc_template_param( $filter, $param_name = 'template', $heading = false, $default_value = false ) {
	if ( ! $heading ) {
		$heading = esc_html__( 'Style', 'phone-repair-plugin' );
	}
	$param = array(
		'param_name' => $param_name,
	);
	if ( 'vc_edit_form' !== vc_post_param( 'action' ) ) {
		$param['type'] = 'hidden';
		$param['value'] = '';
		return $param;
	}
	if ( $default_value ) {
		$templates = apply_filters( $filter, $default_value );
	} else {
		$templates = apply_filters( $filter, array(
			esc_html__( 'Default', 'phone-repair-plugin' ) => '',
		) );
	}
	if ( ! is_array( $templates ) || empty( $templates ) ) {
		$param['type'] = 'hidden';
		$param['value'] = is_string( $templates ) ? $templates : '';
		return $param;
	} else {
		if ( 1 === count( $templates ) ) {
			$param['type'] = 'hidden';
			$param['value'] = reset( $templates );
		} else {
			$param['heading'] = $heading;
			$param['type'] = 'dropdown';
			$param['value'] = $templates;
		}
		return $param;
	}
}

function phone_repair_get_taxonomies_for_filter() {
	$taxonomies = array();
	if ( 'vc_edit_form' === vc_post_param( 'action' ) ) {
		$taxonomies_types = vc_taxonomies_types();
		if ( is_array( $taxonomies_types ) && ! empty( $taxonomies_types ) ) {
			foreach ( $taxonomies_types as $t => $data ) {
				if ( 'post_format' !== $t && is_object( $data ) ) {
					$taxonomies[ $data->labels->name . ' (' . $t . ')' ] = $t;
				}
			}
		}
	}
	return $taxonomies;
}

function phone_repair_get_the_terms( $post, $taxonomy ) {
	$terms = get_the_terms( $post, $taxonomy );
	if ( is_wp_error( $terms ) || empty( $terms ) ) {
		return $terms;
	}
	$term_names = array();
	foreach ( array_values( $terms ) as $term ) {
		$term_names[] = $term->name;
	}
	return $term_names;
}
