<?php
/**
 * Display custom color CSS.
 */
function phone_repair_print_custom_colors() {
	phone_repair_custom_color_css_wrap( 'phone_repair_accent_color', 'phone_repair_accent_color_css' );
	phone_repair_custom_color_css_wrap( 'phone_repair_page_title_background_color', 'phone_repair_page_title_background_color_css' );
	phone_repair_custom_color_css_wrap( 'phone_repair_footer_background_color', 'phone_repair_footer_background_color_css' );
	phone_repair_custom_color_css_wrap( 'phone_repair_footer_bottom_background_color', 'phone_repair_footer_bottom_background_color_css' );
}
add_action( 'wp_head', 'phone_repair_print_custom_colors' );

function phone_repair_custom_color_css_wrap( $mod_name, $print_css_func ) {
	global $phone_repair_defaults;
	$color = get_theme_mod( $mod_name, $phone_repair_defaults[ $mod_name ] );
	if ( $phone_repair_defaults[ $mod_name ] === $color && ! is_customize_preview() ) {
		return;
	}
	$id = 'theme-custom-' . $mod_name;
?>
	<style id="<?php echo esc_attr( $id ) ?>" <?php if ( is_customize_preview() ) { echo 'data-current-color="' . esc_attr( $color ) . '"'; } ?>>
		<?php echo $print_css_func( $color ); // wpcs: xss ok ?>
	</style>
<?php
}

function phone_repair_accent_color_css( $accent_color ) {
	$css = '
.header--text-color_light .topbar a:hover,
.header--text-color_light .topbar a:focus,
.comment__reply,
.comment__reply a,
.testimonial-item__text::before,
.testimonial-item__text::after,
.info-box__icon,
.post-teaser__title a:hover,
.post-teaser__title a:focus,
.entry__title a:hover,
.entry__title a:focus,
.entry-meta__icon,
.entry-meta a:hover,
.entry-meta a:focus,
.quote::before,
.quote::after,
.woocommerce ul.products li.product:hover h3,
.woocommerce ul.products li.product:hover .woocommerce-loop-product__title,
.woocommerce ul.products li.product:hover .woocommerce-loop-category__title {
	color: ' . $accent_color . ';
}

.text-accent,
.color-accent {
	color: ' . $accent_color . ' !important;
}

.pagination .nav-links .page-numbers.current,
.pagination .nav-links .page-numbers.current:hover,
.pagination .nav-links .page-numbers.current:focus,
.post-teaser3:hover .post-teaser3__title,
.post-teaser4__more,
.widget_tag_cloud a:hover, .widget_tag_cloud a:focus,
.widget_product_tag_cloud a:hover,
.widget_product_tag_cloud a:focus,
.woocommerce span.onsale,
.woocommerce nav.woocommerce-pagination ul li span.current,
.woocommerce .widget_price_filter .ui-slider .ui-slider-handle,
.woocommerce .widget_price_filter .ui-slider .ui-slider-range {
	background-color: ' . $accent_color . ';
}

.bg-accent {
	background-color: ' . $accent_color . ' !important;
}

blockquote,
.blockquote-reverse,
.pagination .nav-links .page-numbers.current,
.pagination .nav-links .page-numbers.current:hover,
.pagination .nav-links .page-numbers.current:focus,
.comment__reply a,
.widget--sidebar .widget__title,
.widget_tag_cloud a:hover,
.widget_tag_cloud a:focus,
.widget_product_tag_cloud a:hover,
.widget_product_tag_cloud a:focus,
.woocommerce nav.woocommerce-pagination ul li span.current {
	border-color: ' . $accent_color . ';
}

@media (min-width: 992px) {
	.primary-menu__item > a::before { background-color: ' . $accent_color . '; }

	.rtl .primary-menu__item > a::before { background-color: transparent; }
	.rtl .primary-menu__item > a::after { background-color: ' . $accent_color . '; }
	.rtl .header--text-color_light .primary-menu__item > a::before { background-color: transparent; }
	.rtl .header--text-color_light .primary-menu__item > a::after  { background-color: #fff; }
}';

	return apply_filters( 'phone_repair_accent_color_css', $css, $accent_color );
}

function phone_repair_page_title_background_color_css( $background_color ) {
	$css = '.header__background { background-color: ' . $background_color . '; }';
	return apply_filters( 'phone_repair_page_title_background_color_css', $css, $background_color );
}

function phone_repair_footer_background_color_css( $background_color ) {
	$css = '.footer-widgets { background-color: ' . $background_color . '; }';
	return apply_filters( 'phone_repair_footer_background_color', $css, $background_color );
}

function phone_repair_footer_bottom_background_color_css( $background_color ) {
	$css = '.footer-copyright { background-color: ' . $background_color . '; }';
	return apply_filters( 'phone_repair_footer_bottom_background_color', $css, $background_color );
}
