<?php

function phone_repair_customize_register( $wp_customize ) {
	global $phone_repair_defaults;

	// Custom colors
	$wp_customize->add_setting( 'phone_repair_accent_color', array(
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'phone_repair_sanitize_accent_color',
		'default'           => $phone_repair_defaults['phone_repair_accent_color'],
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'phone_repair_accent_color', array(
		'label'   => __( 'Accent color', 'phone-repair' ),
		'section' => 'colors',
	) ) );

	$wp_customize->add_setting( 'phone_repair_page_title_background_color', array(
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'phone_repair_sanitize_page_title_background_color',
		'default'           => $phone_repair_defaults['phone_repair_page_title_background_color'],
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'phone_repair_page_title_background_color', array(
		'label'   => __( 'Page title background color', 'phone-repair' ),
		'section' => 'colors',
	) ) );

	$wp_customize->add_setting( 'phone_repair_footer_background_color', array(
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'phone_repair_sanitize_footer_background_color',
		'default'           => $phone_repair_defaults['phone_repair_footer_background_color'],
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'phone_repair_footer_background_color', array(
		'label'   => __( 'Footer background color', 'phone-repair' ),
		'section' => 'colors',
	) ) );

	$wp_customize->add_setting( 'phone_repair_footer_bottom_background_color', array(
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'phone_repair_sanitize_footer_bottom_background_color',
		'default'           => $phone_repair_defaults['phone_repair_footer_bottom_background_color'],
	) );
	$wp_customize->add_control( new WP_Customize_Color_Control( $wp_customize, 'phone_repair_footer_bottom_background_color', array(
		'label'   => __( 'Footer bottom background color', 'phone-repair' ),
		'section' => 'colors',
	) ) );

	// Header image
	$wp_customize->add_setting( 'phone_repair_header_image_repeat', array(
		'type'              => 'theme_mod',
		'theme_supports'    => 'custom-header',
		'sanitize_callback' => 'phone_repair_default_sanitize_callback',
		'default'           => $phone_repair_defaults['phone_repair_header_image_repeat'],
	) );
	$wp_customize->add_control( 'phone_repair_header_image_repeat', array(
		'label'      => __( 'Image Repeat', 'phone-repair' ),
		'section'    => 'header_image',
		'type'       => 'radio',
		'choices'    => array(
			'no-repeat'  => __( 'No Repeat', 'phone-repair' ),
			'repeat'     => __( 'Tile', 'phone-repair' ),
			'repeat-x'   => __( 'Tile Horizontally', 'phone-repair' ),
			'repeat-y'   => __( 'Tile Vertically', 'phone-repair' ),
		),
	) );

	$wp_customize->add_setting( 'phone_repair_header_image_position_x', array(
		'type'              => 'theme_mod',
		'theme_supports'    => 'custom-header',
		'sanitize_callback' => 'phone_repair_default_sanitize_callback',
		'default'           => $phone_repair_defaults['phone_repair_header_image_position_x'],
	) );
	$wp_customize->add_control( 'phone_repair_header_image_position_x', array(
		'label'   => __( 'Horizontal Image Positioning', 'phone-repair' ),
		'section' => 'header_image',
		'type'    => 'radio',
		'choices' => array(
			'left'   => __( 'Left', 'phone-repair' ),
			'center' => __( 'Center', 'phone-repair' ),
			'right'  => __( 'Right', 'phone-repair' ),
		),
	) );

	$wp_customize->add_setting( 'phone_repair_header_image_position_y', array(
		'type'              => 'theme_mod',
		'theme_supports'    => 'custom-header',
		'sanitize_callback' => 'phone_repair_default_sanitize_callback',
		'default'           => $phone_repair_defaults['phone_repair_header_image_position_y'],
	) );
	$wp_customize->add_control( 'phone_repair_header_image_position_y', array(
		'label'      => __( 'Vertical Image Positioning', 'phone-repair' ),
		'section'    => 'header_image',
		'type'       => 'radio',
		'choices'    => array(
			'top'       => __( 'Top', 'phone-repair' ),
			'center'    => __( 'Center', 'phone-repair' ),
			'bottom'    => __( 'Bottom', 'phone-repair' ),
		),
	) );

	// Page Title
	$wp_customize->add_section( 'phone_repair_page_title', array(
		'title' => esc_html__( 'Phone Repair: Page Title', 'phone-repair' ),
	) );
	$wp_customize->add_setting( 'phone_repair_page_title_alignment', array(
		'type' => 'theme_mod',
		'default' => '',
		'sanitize_callback' => 'phone_repair_default_sanitize_callback',
	) );

	$wp_customize->add_control( 'phone_repair_page_title_alignment', array(
		'type' => 'select',
		'section' => 'phone_repair_page_title',
		'label' => esc_html__( 'Title Alignment', 'phone-repair' ),
		'choices' => array(
			'' => esc_html__( 'Default', 'phone-repair' ),
			'left' => esc_html__( 'Left', 'phone-repair' ),
			'center' => esc_html__( 'Center', 'phone-repair' ),
			'right' => esc_html__( 'Right', 'phone-repair' ),
		),
	) );

	// Remove the default Header Text Color control, since we are using custom Page Title Text Color.
	$wp_customize->remove_control( 'header_textcolor' );
	$wp_customize->add_setting( 'phone_repair_page_title_text_color', array(
		'type' => 'theme_mod',
		'default' => 'light',
		'sanitize_callback' => 'phone_repair_default_sanitize_callback',
	) );
	$wp_customize->add_control( 'phone_repair_page_title_text_color', array(
		'type' => 'select',
		'section' => 'phone_repair_page_title',
		'label' => esc_html__( 'Title Text Color', 'phone-repair' ),
		'choices' => array(
			'dark' => esc_html__( 'Dark', 'phone-repair' ),
			'light' => esc_html__( 'Light', 'phone-repair' ),
		),
	) );

	$wp_customize->add_setting( 'phone_repair_page_title_vertical_space', array(
		'type' => 'theme_mod',
		'default' => 'normal',
		'sanitize_callback' => 'phone_repair_default_sanitize_callback',
	) );
	$wp_customize->add_control( 'phone_repair_page_title_vertical_space', array(
		'type' => 'select',
		'section' => 'phone_repair_page_title',
		'label' => esc_html__( 'Title Vertical Spacing', 'phone-repair' ),
		'choices' => array(
			'normal' => esc_html__( 'Normal', 'phone-repair' ),
			'large' => esc_html__( 'Large', 'phone-repair' ),
		),
	) );

	// Top bar
	$wp_customize->add_section( 'phone_repair_top_bar', array(
		'title' => __( 'Phone Repair: Top Bar', 'phone-repair' ),
	) );

	$wp_customize->add_setting( 'phone_repair_top_bar_left_text', array(
		'type' => 'theme_mod',
		'transport' => 'postMessage',
		'sanitize_callback' => 'phone_repair_raw_html_sanitize_callback',
	) );
	$wp_customize->add_control( 'phone_repair_top_bar_left_text', array(
		'type' => 'textarea',
		'label' => __( 'Left text', 'phone-repair' ),
		'section' => 'phone_repair_top_bar',
	) );
	$wp_customize->selective_refresh->add_partial( 'phone_repair_top_bar_left_text', array(
		'selector'            => '.topbar__left',
		'container_inclusive' => true,
		'render_callback'     => function() {
			phone_repair_top_bar_content( 'left' );
		},
	) );

	$wp_customize->add_setting( 'phone_repair_top_bar_center_text', array(
		'type' => 'theme_mod',
		'transport' => 'postMessage',
		'sanitize_callback' => 'phone_repair_raw_html_sanitize_callback',
	) );
	$wp_customize->add_control( 'phone_repair_top_bar_center_text', array(
		'type' => 'textarea',
		'label' => __( 'Center text', 'phone-repair' ),
		'section' => 'phone_repair_top_bar',
	) );
	$wp_customize->selective_refresh->add_partial( 'phone_repair_top_bar_center_text', array(
		'selector'            => '.topbar__center',
		'container_inclusive' => true,
		'render_callback'     => function() {
			phone_repair_top_bar_content( 'center' );
		},
	) );

	$wp_customize->add_setting( 'phone_repair_top_bar_right_text', array(
		'type' => 'theme_mod',
		'transport' => 'postMessage',
		'sanitize_callback' => 'phone_repair_raw_html_sanitize_callback',
	) );
	$wp_customize->add_control( 'phone_repair_top_bar_right_text', array(
		'type' => 'textarea',
		'label' => __( 'Right text', 'phone-repair' ),
		'section' => 'phone_repair_top_bar',
	) );
	$wp_customize->selective_refresh->add_partial( 'phone_repair_top_bar_right_text', array(
		'selector'            => '.topbar__right',
		'container_inclusive' => true,
		'render_callback'     => function() {
			phone_repair_top_bar_content( 'right' );
		},
	) );

	// Logo
	$wp_customize->add_section( 'phone_repair_logo', array(
		'title' => __( 'Phone Repair: Logo', 'phone-repair' ),
	) );

	// Header logo
	$wp_customize->add_setting( 'phone_repair_header_logo_url', array(
		'type' => 'theme_mod',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wp_customize->add_control( new WP_Customize_Image_Control(
		$wp_customize,
		'phone_repair_header_logo_url',
		array(
			'label' => __( 'Site logo', 'phone-repair' ),
			'section' => 'phone_repair_logo',
		)
	) );

	$wp_customize->add_setting( 'phone_repair_light_header_logo_url', array(
		'type' => 'theme_mod',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wp_customize->add_control( new WP_Customize_Image_Control(
		$wp_customize,
		'phone_repair_light_header_logo_url',
		array(
			'label' => __( 'Light Site logo (optional)', 'phone-repair' ),
			'section' => 'phone_repair_logo',
		)
	) );

	// Footer copyright area
	$wp_customize->add_section( 'phone_repair_footer_copyright_area', array(
		'title' => __( 'Phone Repair: Footer Copyright', 'phone-repair' ),
	) );

	$wp_customize->add_setting( 'phone_repair_footer_copyright_text', array(
		'type'              => 'theme_mod',
		'transport'         => 'postMessage',
		'sanitize_callback' => 'phone_repair_raw_html_sanitize_callback',
		'default'           => $phone_repair_defaults['phone_repair_footer_copyright_text'],
	) );
	$wp_customize->add_control( 'phone_repair_footer_copyright_text', array(
		'type'    => 'textarea',
		'section' => 'phone_repair_footer_copyright_area',
		'label'   => __( 'Copyright text', 'phone-repair' ),
	) );
	$wp_customize->selective_refresh->add_partial( 'phone_repair_footer_copyright_text', array(
		'selector' => '.site-footer .footer-copyright',
		'render_callback' => 'phone_repair_customize_partial_footer_copyright',
	) );

	// 404 Page section
	$wp_customize->add_section( 'phone_repair_404', array(
		'title' => __( 'Phone Repair: 404 page', 'phone-repair' ),
	) );

	// 404 Page background image
	$wp_customize->add_setting( 'phone_repair_404_image', array(
		'type'              => 'theme_mod',
		'sanitize_callback' => 'esc_url_raw',
	) );
	$wp_customize->add_control( new WP_Customize_Image_Control(
		$wp_customize,
		'phone_repair_404_image',
		array(
			'label' => __( '404 page image', 'phone-repair' ),
			'section' => 'phone_repair_404',
		)
	) );
}
add_action( 'customize_register', 'phone_repair_customize_register' );

function phone_repair_customize_preview_js() {
	wp_enqueue_style( 'phone-repair-customize-preview', get_template_directory_uri() . '/assets/css/customize-preview.css', array(), PHONE_REPAIR_THEME_VERSION );
	wp_enqueue_script( 'phone-repair-customize-preview', get_template_directory_uri() . '/assets/js/customize-preview.js', array( 'customize-preview' ), PHONE_REPAIR_THEME_VERSION, true );
}
add_action( 'customize_preview_init', 'phone_repair_customize_preview_js' );

function phone_repair_sanitize_accent_color( $value ) {
	if ( empty( $value ) ) {
		$value = phone_repair_get_default( 'phone_repair_accent_color' );
	}
	return sanitize_hex_color( $value );
}

function phone_repair_sanitize_page_title_background_color( $value ) {
	if ( empty( $value ) ) {
		$value = phone_repair_get_default( 'phone_repair_page_title_background_color' );
	}
	return sanitize_hex_color( $value );
}

function phone_repair_sanitize_footer_background_color( $value ) {
	if ( empty( $value ) ) {
		$value = phone_repair_get_default( 'phone_repair_footer_background_color' );
	}
	return sanitize_hex_color( $value );
}

function phone_repair_sanitize_footer_bottom_background_color( $value ) {
	if ( empty( $value ) ) {
		$value = phone_repair_get_default( 'phone_repair_footer_bottom_background_color' );
	}
	return sanitize_hex_color( $value );
}

function phone_repair_customize_partial_footer_copyright() {
	get_template_part( 'partials/footer/footer-copyright' );
}

function phone_repair_default_sanitize_callback( $value ) {
	return $value;
}

function phone_repair_trim_sanitize_callback( $value ) {
	return trim( $value );
}

function phone_repair_raw_html_sanitize_callback( $value ) {
	return htmlspecialchars( stripslashes( $value ) );
}

function phone_repair_hex_color_sanitize_callback( $value ) {
	return sanitize_hex_color( $value );
}
