<?php

function phone_repair_categorized_blog() {
	if ( false === ( $all_the_cool_cats = get_transient( 'phone_repair_categories' ) ) ) {
		// Create an array of all the categories that are attached to posts.
		$all_the_cool_cats = get_categories( array(
			'fields'     => 'ids',
			'hide_empty' => 1,
			'number'     => 2,
		) );
		$all_the_cool_cats = count( $all_the_cool_cats );
		set_transient( 'phone_repair_categories', $all_the_cool_cats );
	}
	return $all_the_cool_cats > 1;
}

function phone_repair_category_transient_flusher() {
	if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
		return;
	}
	delete_transient( 'phone_repair_categories' );
}
add_action( 'edit_category', 'phone_repair_category_transient_flusher' );
add_action( 'save_post',     'phone_repair_category_transient_flusher' );

function phone_repair_get_header_class() {
	$class = 'header';
	$text_color = phone_repair_get_the_post_meta( 'phone_repair_header_text_color' );
	if ( ! empty( $text_color ) && 'dark' !== $text_color ) {
		$class .= ' header--text-color_' . $text_color;
	}
	if ( 'yes' === phone_repair_get_the_post_meta( 'phone_repair_transparent_header' ) ) {
		if ( phone_repair_hide_page_title() ) {
			$class .= ' header--position_absolute';
		} else {
			$class .= ' header--transparent';
		}
	}
	return $class;
}

function phone_repair_get_page_title_class() {
	$class = 'page-title';
	// Text color.
	$text_color = phone_repair_get_the_post_meta( 'phone_repair_page_title_text_color' );
	if ( empty( $text_color ) ) {
		$text_color = get_theme_mod( 'phone_repair_page_title_text_color', 'light' );
	}
	if ( ! empty( $text_color ) && 'dark' !== $text_color ) {
		$class .= ' page-title--text-color_' . $text_color;
	}
	// Alignment.
	$alignment = phone_repair_get_the_post_meta( 'phone_repair_page_title_alignment' );
	if ( empty( $alignment ) ) {
		$alignment = get_theme_mod( 'phone_repair_page_title_alignment' );
	}
	if ( ! empty( $alignment ) ) {
		$class .= ' page-title--align_' . $alignment;
	}
	// Vertical spacing.
	$vspace = phone_repair_get_the_post_meta( 'phone_repair_page_title_vertical_space' );
	if ( empty( $vspace ) ) {
		$vspace = get_theme_mod( 'phone_repair_page_title_vertical_space', 'normal' );
	}
	if ( ! empty( $vspace ) && 'normal' !== $vspace ) {
		$class .= ' page-title--vspace_' . $vspace;
	}
	return $class;
}

function phone_repair_get_header_logo_url() {
	$logo_url = '';
	$text_color = phone_repair_get_the_post_meta( 'phone_repair_header_text_color' );
	if ( 'light' === $text_color ) {
		$logo_url = get_theme_mod( 'phone_repair_light_header_logo_url' );
	}
	if ( empty( $logo_url ) ) {
		$logo_url = get_theme_mod( 'phone_repair_header_logo_url' );
	}
	return $logo_url;
}

function phone_repair_hide_page_title() {
	if ( ! is_singular() ) {
		return false;
	}

	$post_meta = phone_repair_get_the_post_meta( 'phone_repair_hide_page_title' );
	if ( '' !== $post_meta ) {
		return 'yes' === $post_meta;
	}

	return is_front_page();
}

function phone_repair_get_page_title() {
	if ( is_front_page() ) {
		return get_bloginfo( 'name' );
	} elseif ( is_search() ) {
		if ( have_posts() ) {
			return esc_html__( 'Search Results', 'phone-repair' );
		} else {
			return esc_html__( 'Nothing found', 'phone-repair' );
		}
	} elseif ( phone_repair_is_woocommerce_activated() && is_woocommerce() ) {
		return woocommerce_page_title();
	} elseif ( is_archive() ) {
		return get_the_archive_title();
	} else {
		return single_post_title( '', false );
	}
}

function phone_repair_get_breadcrumbs() {
	if ( ! function_exists( 'bcn_display' ) ) {
		return false;
	}
	if ( 'yes' === phone_repair_get_the_post_meta( 'phone_repair_hide_breadcrumbs' ) ) {
		return false;
	}
	return bcn_display( true );
}

function phone_repair_get_main_col_class() {
	$class = 'main-col';
	if ( phone_repair_is_vc_enabled_on_page( get_the_ID() ) ) {
		$class .= ' main-col--vc';
	}
	return $class;
}

if ( ! function_exists( 'phone_repair_post_meta' ) ) :
	function phone_repair_post_meta() {
		$post_type = get_post_type();
		$categories = get_the_category_list( esc_html__( ', ', 'phone-repair' ) );
		$tags = get_the_tag_list( '', esc_html__( ', ', 'phone-repair' ) );
		?>
		<?php if ( 'post' === $post_type ) : ?>
			<div class="entry-meta">
				<span class="entry-meta__icon fa fa-calendar"></span>
				<span class="screen-reader-text"><?php echo esc_html_x( 'Posted on', 'Used before publish date.', 'phone-repair' ) ?> </span>
				<a href="<?php echo esc_url( get_permalink() ) ?>" rel="bookmark">
					<time datetime="<?php echo esc_attr( get_the_date( 'c' ) ) ?>"><?php echo esc_html( get_the_date() ) ?></time>
				</a>
			</div>
			<div class="entry-meta">
				<span class="entry-meta__icon fa fa-pencil-square-o"></span>
				<a href="<?php echo esc_url( get_author_posts_url( get_the_author_meta( 'ID' ) ) ) ?>"><?php echo esc_html( get_the_author() ) ?></a>
			</div>
			<?php if ( $categories && phone_repair_categorized_blog() ) : ?>
				<div class="entry-meta"><span class="entry-meta__icon fa fa-folder-o"></span><?php echo wp_kses_post( $categories ) ?></div>
			<?php endif ?>
			<?php if ( $tags ) : ?>
				<div class="entry-meta"><span class="entry-meta__icon fa fa-tag"></span><?php echo wp_kses_post( $tags ) ?></div>
			<?php endif ?>
		<?php endif ?>
		<?php if ( ! is_single() && ! post_password_required() && ( comments_open() || get_comments_number() ) ) : ?>
			<div class="entry-meta">
				<span class="entry-meta__icon fa fa-comment-o"></span>
				<?php
				comments_popup_link( sprintf(
					wp_kses( __( 'Leave a Comment<span class="screen-reader-text"> on %s</span>', 'phone-repair' ), array( 'span' => array( 'class' => array() ) ) ),
					get_the_title()
				) );
				?>
			</div>
		<?php endif ?>
		<?php
	}
endif;

if ( ! function_exists( 'phone_repair_comment_form' ) ) :
	function phone_repair_comment_form() {
		$commenter = wp_get_current_commenter();
		$req       = get_option( 'require_name_email' );
		$html_req  = ( $req ? " required='required'" : '' );
		$fields = array(
			'author' => '<div class="comment-form__author"><input id="author" name="author" type="text" value="' . esc_attr( $commenter['comment_author'] ) . '" placeholder="' . esc_attr_x( 'Name', 'Comment form name field.', 'phone-repair' ) . '" size="30" maxlength="245"' . $html_req . ' /></div>',
			'email'  => '<div class="comment-form__email"><input id="email" name="email" type="email"  value="' . esc_attr( $commenter['comment_author_email'] ) . '" placeholder="' . esc_attr_x( 'Email', 'Comment form email field.', 'phone-repair' ) . '" size="30" maxlength="100" ' . $html_req . ' /></div>',
			'url'    => '',
		);
		$args = array(
			'fields'               => $fields,
			'comment_field'        => '<div class="comment-form__comment"><textarea id="comment" name="comment" cols="45" rows="7" maxlength="65525" placeholder="' . esc_attr_x( 'Comment', 'Comment form comment text field.', 'phone-repair' ) . '" required="required"></textarea></div>',
			'comment_notes_before' => '',
			'class_form'           => 'comment-form',
			'label_submit'         => __( 'Post comment', 'phone-repair' ),
			'class_submit'         => 'button',
			'submit_field'         => '<div class="comment-form__submit">%1$s %2$s</div>',
			'submit_button'        => '<input name="%1$s" type="submit" id="%2$s" class="%3$s" value="%4$s" />',
		);
		comment_form( $args );
	}
endif;

if ( ! function_exists( 'phone_repair_render_comment' ) ) :
	function phone_repair_render_comment( $comment, $args, $depth ) {
		?>
		<li id="comment-<?php comment_ID() ?>" <?php comment_class() ?>>

		<div id="div-comment-<?php comment_ID() ?>" class="comment__box">
			<?php if ( 0 !== $args['avatar_size'] ) : ?>
				<div class="comment__avatar"><?php echo get_avatar( $comment, $args['avatar_size'] ) ?></div>
			<?php endif ?>
			<div class="comment__body">
				<header class="comment__header">
					<div class="comment__author"><?php comment_author_link() ?></div>
					<div class="comment__date">
						<a href="<?php echo esc_url( get_comment_link( $comment->comment_ID ) ) ?>"><?php comment_date() ?> <?php comment_time() ?></a>
						<?php edit_comment_link( _x( '(Edit)', 'Edit comment.', 'phone-repair' ), '  ', '' ) ?>
					</div>
				</header>
				<?php if ( '0' === $comment->comment_approved ) : ?>
					<div class="comment__moderation"><?php echo esc_html( 'Your comment is awaiting moderation.', 'phone-repair' ) ?></div>
				<?php endif ?>
				<div class="comment__text">
					<?php comment_text(); ?>
				</div>
				<?php if ( 0 !== $depth && $depth < $args['max_depth'] && comments_open( $comment->comment_post_ID ) ) : ?>
					<div class="comment__reply">
						<span class="fa fa-reply"></span>
						<?php
						comment_reply_link( array_merge( $args, array(
							'add_below'     => 'div-comment',
							'depth'         => $depth,
							'max_depth'     => $args['max_depth'],
						) ) );
						?>
					</div>
				<?php endif ?>
			</div>
		</div>

		<?php
	}
endif;

if ( ! function_exists( 'phone_repair_hide_top_bar' ) ) {
	function phone_repair_hide_top_bar() {
		if ( 'yes' === phone_repair_get_the_post_meta( 'phone_repair_hide_top_bar' ) ) {
			return true;
		}

		$left_text = get_theme_mod( 'phone_repair_top_bar_left_text' );
		$center_text = get_theme_mod( 'phone_repair_top_bar_center_text' );
		$right_text = get_theme_mod( 'phone_repair_top_bar_right_text' );
		return empty( $left_text ) && empty( $center_text ) && empty( $right_text );
	}
}

if ( ! function_exists( 'phone_repair_top_bar_content' ) ) {
	function phone_repair_top_bar_content( $pos ) {
		$text = html_entity_decode( get_theme_mod( 'phone_repair_top_bar_' . $pos . '_text' ) );
		if ( empty( $text ) ) {
			return;
		}
		?>
		<div class="topbar__<?php echo esc_attr( $pos ); ?>"><?php echo wp_kses( $text, 'phone_repair_top_bar' ) ?></div>
		<?php
	}
}
